@@ -4,5 +4,7 @@ var searchData=
   ['u_5fdisable_5fwebsocket_1',['U_DISABLE_WEBSOCKET',['../ulfius_8h.html#a8d1f2b589f352ad00850d6b63cc2e7f8',1,'ulfius.h']]],
   ['u_5fwebsocket_5fdefault_5fmemory_5flevel_2',['U_WEBSOCKET_DEFAULT_MEMORY_LEVEL',['../u__websocket_8c.html#a97fda19a093a1846de1698e14d1b0c5e',1,'u_websocket.c']]],
   ['u_5fwebsocket_5fdefault_5fwindows_5fbits_3',['U_WEBSOCKET_DEFAULT_WINDOWS_BITS',['../u__websocket_8c.html#ab61b7ad872ea17944db8d0d6b1d9b1bd',1,'u_websocket.c']]],
-  ['unused_4',['UNUSED',['../u__private_8h.html#a86d500a34c624c2cae56bc25a31b12f3',1,'u_private.h']]]
+  ['u_5fwebsocket_5fresponse_5fbuffer_5flen_4',['U_WEBSOCKET_RESPONSE_BUFFER_LEN',['../u__websocket_8c.html#a6811bb44403ea260cd242dcf0ed087bb',1,'u_websocket.c']]],
+  ['u_5fwebsocket_5fsec_5fkey_5flen_5',['U_WEBSOCKET_SEC_KEY_LEN',['../u__websocket_8c.html#ae88bd7d907fabd45ea91b6444b6e5020',1,'u_websocket.c']]],
+  ['unused_6',['UNUSED',['../u__private_8h.html#a86d500a34c624c2cae56bc25a31b12f3',1,'u_private.h']]]
 ];
